list_fields: List of accepted fields for the function country_info

View source: R/list_fields.R

list_fieldsR Documentation

List of accepted fields for the function country_info

Description

This function queries REST Countries API and returns a list of all possible fields that can be used in the function country_info. NOTE: Internet access is needed to download information from the API.

Usage

list_fields()

Value

A vector of accepted fields for the function country_info()

See Also

country_info

Examples

# Run example only if a connection to the API is available
if (check_countries_api(warnings = FALSE)){

list_fields()

}

countries documentation built on June 17, 2026, 9:08 a.m.